@@ -28,11 +28,20 @@
 namespace
 {
 #ifndef IOPRIO_CLASS_IDLE
-enum { IOPRIO_CLASS_NONE, IOPRIO_CLASS_RT, IOPRIO_CLASS_BE, IOPRIO_CLASS_IDLE };
+enum {
+    IOPRIO_CLASS_NONE,
+    IOPRIO_CLASS_RT,
+    IOPRIO_CLASS_BE,
+    IOPRIO_CLASS_IDLE
+};
 #endif
 
 #ifndef IOPRIO_WHO_PROCESS
-enum { IOPRIO_WHO_PROCESS = 1, IOPRIO_WHO_PGRP, IOPRIO_WHO_USER };
+enum {
+    IOPRIO_WHO_PROCESS = 1,
+    IOPRIO_WHO_PGRP,
+    IOPRIO_WHO_USER
+};
 #endif
 
 #ifndef IOPRIO_CLASS_SHIFT
