@@ -6,6 +6,7 @@
  */
 
 #include "scheduler.h"
+using namespace Qt::Literals::StringLiterals;
 
 #include "akonadi_indexer_agent_debug.h"
 #include "collectionindexingjob.h"
@@ -48,7 +49,7 @@ Scheduler::Scheduler(Index &index, const KSharedConfigPtr &config, const QShared
     m_processTimer.setInterval(100ms);
     connect(&m_processTimer, &QTimer::timeout, this, &Scheduler::processNext);
 
-    KConfigGroup cfg = m_config->group(QStringLiteral("General"));
+    KConfigGroup cfg = m_config->group(u"General"_s);
     const auto dirtyCollectionsResult2 = cfg.readEntry("dirtyCollections", QList<Akonadi::Collection::Id>());
     m_dirtyCollections = QSet<Akonadi::Collection::Id>(dirtyCollectionsResult2.begin(), dirtyCollectionsResult2.end());
 
@@ -84,7 +85,7 @@ int Scheduler::numberOfCollectionQueued() const
 
 void Scheduler::collectDirtyCollections()
 {
-    KConfigGroup cfg = m_config->group(QStringLiteral("General"));
+    KConfigGroup cfg = m_config->group(u"General"_s);
     // Store collections where we did not manage to index all, we'll need to do a full sync for them the next time
     QHash<Akonadi::Collection::Id, QQueue<Akonadi::Item::Id>>::ConstIterator it = m_queues.constBegin();
     QHash<Akonadi::Collection::Id, QQueue<Akonadi::Item::Id>>::ConstIterator end = m_queues.constEnd();
@@ -221,7 +222,7 @@ void Scheduler::processNext()
     }
 
     const Akonadi::Collection col(m_collectionQueue.takeFirst());
-    qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Processing collection: " << col.id();
+    qCDebug(AKONADI_INDEXER_AGENT_LOG) << "Processing collection:" << col.id();
     QQueue<Akonadi::Item::Id> &itemQueue = m_queues[col.id()];
     const bool fullSync = m_dirtyCollections.contains(col.id());
     CollectionIndexingJob *job = m_jobFactory->createCollectionIndexingJob(m_index, col, itemQueue, fullSync, this);
@@ -237,7 +238,7 @@ void Scheduler::processNext()
 void Scheduler::slotIndexingFinished(KJob *job)
 {
     if (job->error()) {
-        qCWarning(AKONADI_INDEXER_AGENT_LOG) << "Indexing failed: " << job->errorString();
+        qCWarning(AKONADI_INDEXER_AGENT_LOG) << "Indexing failed:" << job->errorString();
     } else {
         const auto collectionId = job->property("collection").value<Akonadi::Collection::Id>();
         m_dirtyCollections.remove(collectionId);
