@@ -22,20 +22,11 @@ ResultIterator::ResultIterator()
 {
 }
 
-ResultIterator::ResultIterator(const ResultIterator &rhs)
-    : d(rhs.d)
-{
-}
+ResultIterator::ResultIterator(const ResultIterator &rhs) = default;
 
-ResultIterator::~ResultIterator()
-{
-}
+ResultIterator::~ResultIterator() = default;
 
-ResultIterator &ResultIterator::operator=(const ResultIterator &other)
-{
-    d = other.d;
-    return *this;
-}
+ResultIterator &ResultIterator::operator=(const ResultIterator &other) = default;
 
 bool ResultIterator::next()
 {
@@ -51,7 +42,7 @@ QByteArray ResultIterator::id() const
     if (d->store) {
         return d->store->id(d->queryId);
     } else {
-        return QByteArray();
+        return {};
     }
 }
 
@@ -60,7 +51,7 @@ QUrl ResultIterator::url() const
     if (d->store) {
         return d->store->url(d->queryId);
     } else {
-        return QUrl();
+        return {};
     }
 }
 
@@ -69,7 +60,7 @@ QString ResultIterator::text() const
     if (d->store) {
         return d->store->text(d->queryId);
     } else {
-        return QString();
+        return {};
     }
 }
 
@@ -78,6 +69,6 @@ QString ResultIterator::icon() const
     if (d->store) {
         return d->store->icon(d->queryId);
     } else {
-        return QString();
+        return {};
     }
 }
