@@ -7,7 +7,6 @@
  */
 
 #include "searchstore.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "akonadi_search_core_debug.h"
 
@@ -19,6 +18,7 @@ using namespace Qt::Literals::StringLiterals;
 #include <QThreadStorage>
 
 using namespace Akonadi::Search;
+using namespace Qt::Literals::StringLiterals;
 
 SearchStore::SearchStore(QObject *parent)
     : QObject(parent)
@@ -80,7 +80,7 @@ SearchStore::List SearchStore::searchStores()
 
     const QStringList paths = QCoreApplication::libraryPaths();
     for (const QString &libraryPath : paths) {
-        const QString path(libraryPath + QStringLiteral("/pim6/akonadi"));
+        const QString path(libraryPath + u"/pim6/akonadi"_s);
         QDir dir(path);
 
         if (!dir.exists()) {
@@ -103,12 +103,12 @@ SearchStore::List SearchStore::searchStores()
     for (const QString &pluginPath : std::as_const(pluginPaths)) {
         QPluginLoader loader(pluginPath);
 
-        const QVariantMap metadata = loader.metaData().toVariantMap()[QStringLiteral("MetaData")].toMap();
-        if (metadata[QStringLiteral("X-Akonadi-PluginType")].toString() != "SearchStore"_L1) {
+        const QVariantMap metadata = loader.metaData().toVariantMap()[u"MetaData"_s].toMap();
+        if (metadata[u"X-Akonadi-PluginType"_s].toString() != "SearchStore"_L1) {
             continue;
         }
         if (!loader.load()) {
-            qCWarning(AKONADI_SEARCH_CORE_LOG) << "Could not create Akonadi Search Store: " << pluginPath;
+            qCWarning(AKONADI_SEARCH_CORE_LOG) << "Could not create Akonadi Search Store:" << pluginPath;
             qCWarning(AKONADI_SEARCH_CORE_LOG) << loader.errorString();
             continue;
         }
@@ -117,9 +117,9 @@ SearchStore::List SearchStore::searchStores()
             SearchStore *ex = qobject_cast<SearchStore *>(obj);
             if (ex) {
                 stores << QSharedPointer<SearchStore>(ex);
-                qCDebug(AKONADI_SEARCH_CORE_LOG) << " Loaded plugins: " << pluginPath;
+                qCDebug(AKONADI_SEARCH_CORE_LOG) << "Loaded plugins:" << pluginPath;
             } else {
-                qCDebug(AKONADI_SEARCH_CORE_LOG) << "Plugin could not be converted to an Akonadi::Search::SearchStore " << pluginPath;
+                qCDebug(AKONADI_SEARCH_CORE_LOG) << "Plugin could not be converted to an Akonadi::Search::SearchStore" << pluginPath;
             }
         } else {
             qCDebug(AKONADI_SEARCH_CORE_LOG) << "Plugin could not create instance" << pluginPath;
