@@ -5,6 +5,8 @@
 */
 
 #include "akonadisearchsyntaxhighlighter.h"
+using namespace Qt::Literals::StringLiterals;
+
 using namespace Akonadi::Search;
 
 AkonadiSearchSyntaxHighlighter::AkonadiSearchSyntaxHighlighter(QTextDocument *doc)
@@ -33,45 +35,45 @@ void AkonadiSearchSyntaxHighlighter::init()
     testFormat.setFontWeight(QFont::Bold);
     QStringList testType;
     // Collection
-    testType << QStringLiteral("C\\d+");
+    testType << u"C\\d+"_s;
 
     // Emails:
     // From
-    testType << QStringLiteral("\\bF");
+    testType << u"\\bF"_s;
     // To
-    testType << QStringLiteral("\\bT");
+    testType << u"\\bT"_s;
     // CC
-    testType << QStringLiteral("\\bCC");
+    testType << u"\\bCC"_s;
     // BC
-    testType << QStringLiteral("\\bBC");
+    testType << u"\\bBC"_s;
     // Organization
-    testType << QStringLiteral("\\bO");
+    testType << u"\\bO"_s;
     // Reply To
-    testType << QStringLiteral("\\bRT");
+    testType << u"\\bRT"_s;
     // Resent-from
-    testType << QStringLiteral("\\bRF");
+    testType << u"\\bRF"_s;
     // List Id
-    testType << QStringLiteral("\\bLI");
+    testType << u"\\bLI"_s;
     // X-Loop
-    testType << QStringLiteral("\\bXL");
+    testType << u"\\bXL"_s;
     // X-Mailing-List
-    testType << QStringLiteral("\\bXML");
+    testType << u"\\bXML"_s;
     // X-Spam-Flag
-    testType << QStringLiteral("\\bXSF");
+    testType << u"\\bXSF"_s;
     // BO body element
-    testType << QStringLiteral("\\bBO");
+    testType << u"\\bBO"_s;
 
     // Contacts:
     // Name
-    testType << QStringLiteral("\\bNA");
+    testType << u"\\bNA"_s;
     // NickName
-    testType << QStringLiteral("\\bNI");
+    testType << u"\\bNI"_s;
 
     // Calendar
-    testType << QStringLiteral("\\bO");
-    testType << QStringLiteral("\\bPS");
-    testType << QStringLiteral("\\bS");
-    testType << QStringLiteral("\\bL");
+    testType << u"\\bO"_s;
+    testType << u"\\bPS"_s;
+    testType << u"\\bS"_s;
+    testType << u"\\bL"_s;
     for (const QString &s : std::as_const(testType)) {
         const QRegularExpression regex(s);
         m_rules.append(Rule(regex, testFormat));
